Principal
=========

Need per principal config:

- calendar home sets
- addressbook home sets
- user address set
- infit settings

Calendar
========

Need per calendar config:

- color
- description
- inbox URL
- outbox URL
- max instances
- max attendees per instance
- calendar timezone

Addresssbook
============

Need per addressbook config:

- max image size
- max resource size
- color
- description
